DataTables examples - Advanced initialisation

# DataTables example Advanced initialisation

The configuration options offered by DataTables extend much further than the options shown in the basic initialisation of this documentation. Through combinations of the options available and the use of callbacks, DataTables is completely customisable and will fit into exactly what you need for your table display.

This section shows some more advanced initialisation options. Keep in mind also that each example can be combined with the other examples to get what you want!